# BanditEval

<p align="center">
  <img src="assets/bandit.png" alt="BanditEval Logo" width="200"/>
</p>

[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Python 3.11+](https://img.shields.io/badge/python-3.11+-blue.svg)](https://www.python.org/downloads/)

BanditEval is the official package for _On Speeding Up Language Model Evaluation_.

<p align="center">
  <img src="assets/resource_savings.png" alt="BanditEval Performance" width="600"/>
</p>

## Installation

```bash
# Basic installation
pip install banditeval

# With examples dependencies
pip install banditeval[examples]

# With development tools
pip install banditeval[dev]
```

## Citing Our Work

If you use BanditEval in your research, please cite:

```bibtex
@inproceedings{
zhou2025on,
title={On Speeding Up Language Model Evaluation},
author={Jin Peng Zhou and Christian K Belardi and Ruihan Wu and Travis Zhang and Carla P Gomes and Wen Sun and Kilian Q Weinberger},
booktitle={The Thirteenth International Conference on Learning Representations},
year={2025},
url={https://openreview.net/forum?id=3cvwO5DBZn}
}
```
